@@ -62,26 +62,28 @@ class _basehelpers:
             if not x.exists():
                 raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), inp)
 
-class _inpchecker:
-    def __init__(self, inp1, inp2, ftype):
-        """Runs all the functions of the _basehelpers class. 
+def _inpchecker(inp1, inp2, ftype):
+    """Runs all the functions of the _basehelpers class. 
 
-        Args:
-            * `inp1` ([type]: `str`): Input file/directory.
-            * `inp2` ([type]: `str`): Output file/directory.
-            * `ftype` ([type]: `str`): Type of file to check for.
-        """
+    Args:
+        * `inp1` ([type]: `str`): Input file/directory.
+        * `inp2` ([type]: `str`): Output file/directory.
+        * `ftype` ([type]: `str`): Type of file to check for.
+    """
 
-        self.inp1 = inp1
-        self.inp2 = inp2
-        self.ftype = ftype
+    basehelpers = _basehelpers(inp1, inp2, fmtype = ftype)
+    basehelpers._format_check()  # Check if objects are of ftype.
+    basehelpers._pathcheck() # Check for the existance of the input paths.
 
-    def initchecker(self):
-        basehelpers = _basehelpers(self.inp1, self.inp2, self.ftype)
-        basehelpers._format_check()  # Check if objects are of ftype.
-        basehelpers._pathcheck() # Check for the existance of the input paths.
-
-class _helpers():
+class _helpers:
+    """Contains multiple static helper functions, which include:
+    >>> sminp(inp, outext)
+    >>> outpath(dinput, flinput)
+    >>> compatibility(__inpobj__, __compat__)
+    >>> typencd(__inpobj__)
+    >>> typecheck(__object__)
+    >>> outpath(dinput, flinput)
+    """
 
     @staticmethod
     def sminp(inp, outext):
@@ -118,7 +120,7 @@ class _helpers():
 
     @staticmethod
     def compatibility(__inpobj__, __compat__):
-        """Check for file compatibility. 
+        """Check for file/s compatibility.
 
         Removes elements from an object (`__inpobj__`) that don't contain substrings
         equal to any of the substring of another list (`__compat__`).
@@ -268,7 +270,8 @@ class txtconvert:
         else:
             type_check = False
             dir_contents = None # __file__ instance is not a parent/child directory.
-            checkfl = self.__file__.lower().endswith(extensions) # Check __file__ instance file type.
+            exttup = tuple(extensions)  # Used in checkfl for .lower().
+            checkfl = self.__file__.lower().endswith(exttup) # Check __file__ instance file type.
 
         # __file__ instance is a parent/child directory and contains at least 1 .txt file.
         if type_check == True and checktxt == True:              
@@ -289,8 +292,9 @@ class txtconvert:
             with open(self.__file__, 'r', encoding = enc) as inf:  
                 line = inf.read()
                 doc.add_paragraph(line)
-                output = doc.save(_helpers.outpath(dinput = self.__d__, flinput = self.__file__) + ".docx") # full path of output .docx file to save.
-            print(f'Conversion complete! New file is saved in {output}.')
+                outpath = self.__d__
+                doc.save(_helpers.outpath(dinput = outpath, flinput = self.__file__) + ".docx") # full path of output .docx file to save.
+            print(f'Conversion complete! New file is saved in {outpath}.')
 
         # __file__ instance is neither a parent/child directory or a file in .txt format. 
         else:
@@ -353,7 +357,7 @@ class imgconvert:
             raise ValueError(f'__d__ must be a directory and a Type: string, not equal to {__d__} and of Type: {(type(__d__)).__name__}.')
 
     def _pdfconv(self, __inp__, __outd__):
-        """Inner function to convert a file to pdf.
+        """Inner function to convert an image file to pdf.
 
         Args:
             * `__inp__` ([type]: `str`): Input file
@@ -371,8 +375,8 @@ class imgconvert:
         pdf_image.save(flsave)
         return flsave
 
-    def _64conv(self, __inp__, __outd__):
-        """Inner function to convert a file to base64 UTF-8 encryption (.txt format).
+    def _64conv(self, __inp__, __outd__, enctp):
+        """Inner function to convert an image file to base64 UTF-8 encryption (.txt format).
 
         Args:
             * `__inp__` ([type]: `str`): Input file.
@@ -384,17 +388,17 @@ class imgconvert:
 
         with open(__inp__, "rb") as img:
             base64_str = base64.b64encode(img.read())
-            base64utf8 = base64_str.decode('utf-8') # Encode to UTF-8 standard.
+            base64_enctp = base64_str.decode(enctp) # Encode to UTF-8 standard.
             file_name = os.path.splitext(os.path.basename(__inp__))[0]
             subdir = os.path.join(__outd__, file_name)
             txt_f = (subdir + '.txt')
 
             with open(txt_f, "w") as txt:
-                txt.write(base64utf8)
+                txt.write(base64_enctp)
             return txt_f
 
     def _imgbnr(self, __inp__, __outd__, __kp__, __bw__):
-        """Inner function to convert a file to binary. Original file format type is kept the same.
+        """Inner function to convert an image file to binary. Original file format type is kept the same.
 
         Args:
             * `__inp__` ([type]: `str`): Input file.
@@ -472,8 +476,22 @@ class imgconvert:
         else:
             raise TypeError(f"{self.__file__} must either be a directory that contains at least 1 supported image file or an individual supported image file.")
 
-    def img_base64(self):
-        """Encode an image file or directory with images to base64 (`UTF-8`) and save it as `.txt`
+    def img_base64(self, encode_type = 'utf-8'):
+        """Encode an image file or directory with images to base64 and save it as `.txt`
+        
+        Args:
+            * `encode_type` ([type]: `str`, default = `utf-8`): Type of byte encoding. Default is utf-8 if not specified.
+
+        Supported encoding types:
+            * `utf-8`, `utf-16`, `utf-32`, `ascii`
+
+        Supported file format inputs:
+
+        * `.png`, `.jpeg`, `.jpg`, `.dng`, `.raw`, `.cr2`, `.crw`, `.erf`, `.raf`, `.tif`,
+
+        * `.tiff`, `.kdc`, `.dcr`, `.mos`, `.mef`, `.nef`, `.orf`, `.rw2`, `.pef`,
+
+        * `.x3f`, `.srw`, `.srf`, `.sr2`, `.arw`, `.mdc`, `.bmp`, `.mrw`
         """
 
         _inpchecker(inp1 = self.__file__, inp2 = self.__d__, ftype = str)  # Check if objects are strings and for the existance of the input paths.
@@ -488,16 +506,22 @@ class imgconvert:
                 '.DCR', '.MOS', '.MEF', '.NEF', '.ORF', '.RW2', '.PEF', '.X3F', '.SRW', '.SRF', '.SR2', '.ARW', '.MDC', '.MRW', 
                 '.jpeg', '.png', '.jpg', '.JPEG', '.PNG', '.JPG')
 
+        # Supported encoding type.
+        supp_enc = ('utf-8', 'utf-16', 'utf-32', 'ascii')
+        if not encode_type in supp_enc:
+            x = ','.join([str(" " + i) for i in supp_enc])
+            raise TypeError(f'{encode_type} encoding type is not supported. Only{x} encodings are supported.')
+
         # __file__ is a parent/child directory.
         if type_check == True:
             dir_contents = _helpers.compatibility(__inpobj__ = self.__file__, __compat__ = supp_ext)
-            for f in tqdm(dir_contents, desc = 'Converting %i files to base64 format' %len(dir_contents) , unit=' Files', disable = self.disable):  # Iterate over all the entries
+            for f in tqdm(dir_contents, desc = 'Converting %i files to base64 format with %s encoding' %(len(dir_contents), encode_type), unit=' Files', disable = self.disable):  # Iterate over all the entries
                 flinp = os.path.join(self.__file__, f)
-                self._64conv(__inp__ = flinp, __outd__ = self.__d__) 
+                self._64conv(__inp__ = flinp, __outd__ = self.__d__, enctp = encode_type) 
 
         else:
-            print(f'Converting {self.__file__} into base64 format with UTF-8 encoding.')
-            output = self._64conv(__inp__ = self.__file__, __outd__ = self.__d__)
+            print(f'Converting {self.__file__} into base64 format with {encode_type} encoding.')
+            output = self._64conv(__inp__ = self.__file__, __outd__ = self.__d__, enctp = encode_type)
             print(f'Conversion complete! New file is saved in {output}.')   
 
     def img_pdf(self):
@@ -569,7 +593,7 @@ class imgconvert:
 
         def _tojpg(flname, infl):   # Used in type_check if and elif statements.
             """Local function that converts the input image file to .jpeg/.jpg.
-            
+
             Returns:
                 ([type]: `str`): The full path of the output .jpeg/.jpg file."""
 
@@ -609,7 +633,7 @@ class imgconvert:
             """Local function that assigns the name and path of the output file.
 
             Returns:
-                ([type]: `str`): The full path of the output file [0] and the full path of the input file [1]."""
+                ([type]: `str`): The full path of the output file [0] and the full path of the input file."""
 
             flpath = os.path.join(obj, fl)
             file_name = os.path.splitext(os.path.basename(flpath))[0]
@@ -640,7 +664,7 @@ class imgconvert:
             print(f'Converting {self.__file__} into .jpeg format.')        
             output = _tojpg(flname = subdir, infl = self.__file__)
             print(f'Conversion complete! New file is saved in {output}.')  
-        
+
         # __file__ is not a parent/child directory, desired format is JPG.
         elif type_check == False and self.__file__.endswith(ext) and format == ".jpg":        
             subdir = _helpers.outpath(dinput = self.__d__, flinput = self.__file__)
@@ -671,7 +695,7 @@ class sheetconvert:
 
     Functions:
         >>> convertsh(totype)
-    
+
     Example:
         >>> from flconverters import sheetconvert
         >>> a = sheetconvert(__file__ = 'path/to/file/or/dir', __d__ = 'path/to/output/dir')
@@ -905,4 +929,7 @@ class sheetconvert:
                                                     # totype extension are the same.
             print(f'Converting {self.__file__} into {totype} format...') 
             output = self._conversion_method(__inp__ = self.__file__, outdir = self.__d__, typeinp = totype)
-            print(f'Conversion complete! New file is saved in {output}.')
\ No newline at end of file
+            print(f'Conversion complete! New file is saved in {output}.')
+
+if __name__ == "__main__":
+    a = imgconvert(__file__ = r'E:\Documents\Python_Scripts\converters\flconverters\circle_20_random.tif').img_base64(encode_type = 'adsaadaas')
\ No newline at end of file
